==> nsRFA_0.6-9.zip: nsRFA/doc/MSClaio2008.R <==
###################################################
### chunk number 1: 
###################################################
library(nsRFA)


###################################################
### chunk number 2: 
###################################################
data(FEH1000)


###################################################
### chunk number 3: 
###################################################
sitedata <- am[am[,1]==69023, ]


###################################################
### chunk number 4: 
###################################################
serieplot(sitedata[,4], sitedata[,3], ylim=c(0,200), xlab="year", ylab="Max annual peak [m3/s]")


###################################################
### chunk number 5: 
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="AIC")
MSC


###################################################
### chunk number 6: 
###################################################
summary(MSC)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## help(MSClaio2008)


###################################################
### chunk number 8: 
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="AICc")
MSC
summary(MSC)


###################################################
### chunk number 9: 
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="BIC")
MSC
summary(MSC)


###################################################
### chunk number 10: 
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="ADC")
MSC
summary(MSC)


###################################################
### chunk number 11: 
###################################################
MSC <- MSClaio2008(sitedata[,4])
MSC


###################################################
### chunk number 12: 
###################################################
summary(MSC)


###################################################
### chunk number 13: 
###################################################
plot(MSC)

==> nsRFA_0.7-17.zip: nsRFA/doc/MSClaio2008.R <==
### R code from vignette source 'MSClaio2008.Rnw'

###################################################
### code chunk number 1: MSClaio2008.Rnw:60-61
###################################################
library(nsRFA)


###################################################
### code chunk number 2: MSClaio2008.Rnw:64-65
###################################################
data(FEH1000)


###################################################
### code chunk number 3: MSClaio2008.Rnw:68-69
###################################################
sitedata <- am[am[,1]==69023, ]


###################################################
### code chunk number 4: MSClaio2008.Rnw:75-77
###################################################
serieplot(sitedata[,4], sitedata[,3], ylim=c(0,200), 
          xlab="year", ylab="Max annual peak [m3/s]")


###################################################
### code chunk number 5: MSClaio2008.Rnw:99-101
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="AIC")
MSC


###################################################
### code chunk number 6: MSClaio2008.Rnw:104-105
###################################################
summary(MSC)


###################################################
### code chunk number 7: MSClaio2008.Rnw:108-109 (eval = FALSE)
###################################################
## help(MSClaio2008)


###################################################
### code chunk number 8: MSClaio2008.Rnw:116-119
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="AICc")
MSC
summary(MSC)


###################################################
### code chunk number 9: MSClaio2008.Rnw:131-134
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="BIC")
MSC
summary(MSC)


###################################################
### code chunk number 10: MSClaio2008.Rnw:152-155
###################################################
MSC <- MSClaio2008(sitedata[,4], crit="ADC")
MSC
summary(MSC)


###################################################
### code chunk number 11: MSClaio2008.Rnw:165-167
###################################################
MSC <- MSClaio2008(sitedata[,4])
MSC


###################################################
### code chunk number 12: MSClaio2008.Rnw:170-171
###################################################
summary(MSC)


###################################################
### code chunk number 13: MSClaio2008.Rnw:177-178
###################################################
plot(MSC)
